@@ -8,6 +8,7 @@ import json
 import requests
 import socket
 from fast_tracker import config
+from fast_tracker.fast_tracker import FastTracker
 from fast_tracker.loggings import logger
 from fast_tracker.client import ServiceManagementClient, TraceSegmentReportService
 from fast_tracker.report.report_struct import ReportStruct
@@ -115,16 +116,18 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
     def _get_data(self, segment, span):
         """
         udp 数据包组装
-        :param generator:
+        :param segment:
+        :param span:
         :return:
         """
+        ft = FastTracker()
         report_struct = ReportStruct()
         report_struct.product_code = config.product_code
         report_struct.app_code = config.app_code
         report_struct.service_name = config.service_name
-        report_struct.env_code = config.env_code
-        report_struct.tenant_code = config.tenant_code
-        report_struct.user_code = config.user_code
+        report_struct.env_code = ft.env_code
+        report_struct.tenant_code = ft.tenant_code
+        report_struct.user_code = ft.user_code
         report_struct.trace_id = str(segment.related_traces[0])
         report_struct.parent_span_id = span.pid
         report_struct.span_id = span.sid
@@ -154,10 +157,7 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         if not tags_data:
             return data
         for tag in tags_data:
-            if tag.key == tags.HttpStatus:
-                data[tag.key] = str(tag.val)
-            else:
-                data[tag.key] = tag.val
+            data[tag.key] = str(tag.val)
 
         return data
 
