@@ -4,51 +4,19 @@
 """
     created by FAST-DEV 2021/4/12
 """
+
 from fast_tracker import config, Layer, ComponentType, Log, LogItem
 from fast_tracker.trace.context import get_context
 from fast_tracker.trace.tags import Tag
 
+custom_user_code = ""
+custom_tenant_code = ""
+custom_env_code = ""
+
 
 class FastTracker:
     def __init__(self):
         self.span = None
-        self.custom_user_code = ""
-        self.custom_tenant_code = ""
-        self.custom_env_code = ""
-
-    @property
-    def enable(self):
-        """
-        获取enable值
-        :return:
-        """
-        return config.enable
-
-    @enable.setter
-    def enable(self, enable: bool = False):
-        """
-        设置enable值
-        :param enable:
-        :return:
-        """
-        config.set_enable(enable)
-
-    @property
-    def env_code(self):
-        """
-        获取 env_code 值
-        :return:
-        """
-        return config.env_code
-
-    @env_code.setter
-    def env_code(self, env_code: str = ""):
-        """
-        设置 env_code 值
-        :param env_code:
-        :return:
-        """
-        config.set_env_code(env_code)
 
     @property
     def product_code(self):
@@ -84,49 +52,14 @@ class FastTracker:
         """
         config.set_app_code(app_code)
 
-    @property
-    def tenant_code(self):
-        """
-        获取 tenant_code 值
-        :return:
-        """
-        return config.tenant_code
-
-    @tenant_code.setter
-    def tenant_code(self, tenant_code: str = ""):
-        """
-        设置 tenant_code 值
-        :param tenant_code:
-        :return:
-        """
-        self.custom_tenant_code = tenant_code
-        config.set_tenant_code(tenant_code)
-
-    @property
-    def user_code(self):
-        """
-        获取 user_code 值
-        :return:
-        """
-        return config.user_code
-
-    @user_code.setter
-    def user_code(self, user_code: str = ""):
-        """
-        设置 user_code 值
-        :param user_code:
-        :return:
-        """
-        self.custom_user_code = user_code
-        config.set_user_code(user_code)
-
     @property
     def env_code(self):
         """
         获取 env_code 值
         :return:
         """
-        return config.env_code
+        global custom_env_code
+        return custom_env_code if custom_env_code else config.env_code
 
     @env_code.setter
     def env_code(self, env_code: str = ""):
@@ -135,8 +68,53 @@ class FastTracker:
         :param env_code:
         :return:
         """
+        if env_code:
+            global custom_env_code
+            custom_env_code = env_code
         config.set_env_code(env_code)
 
+    @property
+    def tenant_code(self):
+        """
+        获取 tenant_code 值
+        :return:
+        """
+        global custom_tenant_code
+        return custom_tenant_code if custom_tenant_code else config.tenant_code
+
+    @tenant_code.setter
+    def tenant_code(self, tenant_code: str = ""):
+        """
+        设置 tenant_code 值
+        :param tenant_code:
+        :return:
+        """
+        if tenant_code:
+            global custom_tenant_code
+            custom_tenant_code = tenant_code
+        config.set_tenant_code(tenant_code)
+
+    @property
+    def user_code(self):
+        """
+        获取 user_code 值
+        :return:
+        """
+        global custom_user_code
+        return custom_user_code if custom_user_code else config.user_code
+
+    @user_code.setter
+    def user_code(self, user_code: str = ""):
+        """
+        设置 user_code 值
+        :param user_code:
+        :return:
+        """
+        if user_code:
+            global custom_user_code
+            custom_user_code = user_code
+        config.set_user_code(user_code)
+
     @property
     def service_name(self):
         """
@@ -246,67 +224,43 @@ class FastTracker:
             "CarrierHeader": config.carrier_header,
         }
 
-    def begin_log(self):
+    def begin_event(self, op: str = ""):
         """
         log模块开始 类似数据库事务的begin_trasaction
+        :param op:
         :return:
         """
-        context = get_context()
-        span = context.active_span()
-        self.span = context.new_local_span(op="execute")
-        self.span.layer = Layer.Local
-        self.span.component = ComponentType.CustomLog
-        self.span.pid = span.sid
-        self.span.start()
-        return self
-        # # with 语法后不需要start和stop 普通模式需要start和stop
-        # with context.new_local_span(op="execute") as self.span:
-        #     self.span.layer = Layer.Local
-        #     self.span.component = ComponentType.CustomLog
-        #     self.span.pid = span.sid
-        #     # self.span.start()
-        #
-        #     return self
+        try:
+            context = get_context()
+            span = context.active_span()
+            self.span = context.new_local_span(op="execute")
+            self.span.layer = Layer.Local
+            self.span.component = ComponentType.CustomEvent
+            self.span.op = op
+            self.span.pid = span.sid
+            self.span.start()
+            return self
+        except Exception as e:
+            raise e
 
-    def debug(self, msg: str = ""):
+    def tag(self, tag_name: str = ""):
         if not self.span:
-            raise RuntimeError("请先调用begin_log实例化log对象")
-        self.span.logs.append(Log(items=[LogItem(key="Debug", val=self.log_covert("Debug", msg))]))
+            raise RuntimeError("请先调用begin_event进行实例化")
+        self.span.tag(Tag(key=ComponentType.CustomEvent, val=tag_name))
 
-    def info(self, msg: str = ""):
+    def log(self, log: str = ""):
         if not self.span:
-            raise RuntimeError("请先调用begin_log实例化log对象")
-        self.span.logs.append(Log(items=[LogItem(key="Info", val=self.log_covert("Info", msg))]))
+            raise RuntimeError("请先调用begin_event进行实例化")
+        self.span.logs.append(Log(items=[LogItem(key=ComponentType.CustomEvent, val=self.log_covert(log))]))
 
-    def warning(self, msg: str = ""):
-        if not self.span:
-            raise RuntimeError("请先调用begin_log实例化log对象")
-        self.span.logs.append(Log(items=[LogItem(key="Warning", val=self.log_covert("Warning", msg))]))
+    def log_covert(self, msg: str = ""):
+        return {"err_msg": msg, "err_type": "", "err_trace": ""}
 
-    def error(self, msg: str = ""):
-        if not self.span:
-            raise RuntimeError("请先调用begin_log实例化log对象")
-        self.span.logs.append(Log(items=[LogItem(key="Error", val=self.log_covert("Error", msg))]))
-
-    def critical(self, msg: str = ""):
-        if not self.span:
-            raise RuntimeError("请先调用begin_log实例化log对象")
-        self.span.logs.append(Log(items=[LogItem(key="Critical", val=self.log_covert("Critical", msg))]))
-
-    def log(self, msg: str = "", level: str = ""):
-        if not self.span:
-            raise RuntimeError("请先调用begin_log实例化log对象")
-        self.span.logs.append(Log(items=[LogItem(key=level.capitalize(), val=self.log_covert(level, msg))]))
-
-    def log_covert(self, level: str = "Debug", msg: str = ""):
-        return {"err_msg": msg, "err_type": level, "err_trace": ""}
-
-    def end_log(self):
+    def end_event(self):
         """
         log模块结束
         :return:
         """
         if not self.span:
-            raise RuntimeError("请先调用begin_log实例化log对象")
-        # with 语法后不需要start和stop 普通模式需要start和stop，取决于begin_log
+            raise RuntimeError("请先调用begin_event进行实例化")
         self.span.stop()
