@@ -55,7 +55,16 @@ class FastTrackerConfiger:
                     for config_key in config_dict.keys():
                         if config_key in default_config_keys:
                             func_name = "set_" + functions.lower_case_name(config_key)
-                            getattr(config, func_name)(config_dict.get(config_key))
+                            if config_key == "TenantCodeReader":
+                                config.set_tenant_code_reader(**config_dict.get(config_key))
+                            elif config_key == "UserCodeReader":
+                                config.set_user_code_reader(**config_dict.get(config_key))
+                            elif config_key == "EnvCodeReader":
+                                config.set_env_code_reader(**config_dict.get(config_key))
+                            elif config_key == "CarrierHeader":
+                                config.set_carrier_header(**config_dict.get(config_key))
+                            else:
+                                getattr(config, func_name)(config_dict.get(config_key))
 
         except Exception as e:
             raise exceptions.ConfigurationError("json格式配置文件格式不合法(不要有注释),解析失败,文件: %s, 错误信息：%s" % (config_file, str(e)))
